@@ -1,5 +1,6 @@
 #define   MYesNo             "_Yes_No"
 #define   MYesNoAll          "_Yes_No_All"
+#define   MYesNoAllQ         "_Yes_No_All_nEver_Quit"
 #define   MYesNoAllRenQ      "_Yes_No_All_nEver_Rename_Quit"
 #define   MContinueQuit      "_Continue_Quit"
 #define   MRetryAbort        "_Retry_Abort"
@@ -52,6 +53,7 @@
 #define   MCHelpSwAC         "\n  ac            Clear Archive attribute after compression or extraction"
 #define   MCHelpSwAD         "\n  ad            Append archive name to destination path"
 #define   MCHelpSwAG         "\n  ag[format]    Generate archive name using the current date"
+#define   MCHelpSwAI         "\n  ai            Ignore file attributes"
 #define   MCHelpSwAO         "\n  ao            Add files with Archive attribute set"
 #define   MCHelpSwAP         "\n  ap<path>      Set path inside archive"
 #define   MCHelpSwAS         "\n  as            Synchronize archive contents"
@@ -63,7 +65,9 @@
 #define   MCHelpSwCU         "\n  cu            Convert names to upper case"
 #define   MCHelpSwDF         "\n  df            Delete files after archiving"
 #define   MCHelpSwDH         "\n  dh            Open shared files"
+#define   MCHelpSwDR         "\n  dr            Delete files to Recycle Bin"
 #define   MCHelpSwDS         "\n  ds            Disable name sort for solid archive"
+#define   MCHelpSwDW         "\n  dw            Wipe files after archiving"
 #define   MCHelpSwEa         "\n  e[+]<attr>    Set file exclude and include attributes"
 #define   MCHelpSwED         "\n  ed            Do not add empty directories"
 #define   MCHelpSwEE         "\n  ee            Do not save and extract extended attributes"
@@ -90,9 +94,8 @@
 #define   MCHelpSwMT         "\n  mt<threads>   Set the number of threads"
 #define   MCHelpSwN          "\n  n<file>       Include only specified file"
 #define   MCHelpSwNa         "\n  n@            Read file names to include from stdin"
-#define   MCHelpSwNal        "\n  n@<list>      Include files in specified list file"
-#define   MCHelpSwOp         "\n  o+            Overwrite existing files"
-#define   MCHelpSwOm         "\n  o-            Do not overwrite existing files"
+#define   MCHelpSwNal        "\n  n@<list>      Include files listed in specified list file"
+#define   MCHelpSwO          "\n  o[+|-]        Set the overwrite mode"
 #define   MCHelpSwOC         "\n  oc            Set NTFS Compressed attribute"
 #define   MCHelpSwOL         "\n  ol            Save symbolic links as the link instead of the file"
 #define   MCHelpSwOR         "\n  or            Rename files automatically"
@@ -101,13 +104,14 @@
 #define   MCHelpSwP          "\n  p[password]   Set password"
 #define   MCHelpSwPm         "\n  p-            Do not query password"
 #define   MCHelpSwR          "\n  r             Recurse subdirectories"
+#define   MCHelpSwRm         "\n  r-            Disable recursion"
 #define   MCHelpSwR0         "\n  r0            Recurse subdirectories for wildcard names only"
 #define   MCHelpSwRI         "\n  ri<P>[:<S>]   Set priority (0-default,1-min..15-max) and sleep time in ms"
 #define   MCHelpSwRR         "\n  rr[N]         Add data recovery record"
 #define   MCHelpSwRV         "\n  rv[N]         Create recovery volumes"
 #define   MCHelpSwS          "\n  s[<N>,v[-],e] Create solid archive"
 #define   MCHelpSwSm         "\n  s-            Disable solid archiving"
-#define   MCHelpSwSC         "\n  sc<chr><obj>  Specify the character set"
+#define   MCHelpSwSC         "\n  sc<chr>[obj]  Specify the character set"
 #define   MCHelpSwSFX        "\n  sfx[name]     Create SFX archive"
 #define   MCHelpSwSI         "\n  si[name]      Read data from standard input (stdin)"
 #define   MCHelpSwSL         "\n  sl<size>      Process files with size less than specified"
@@ -131,7 +135,7 @@
 #define   MCHelpSwW          "\n  w<path>       Assign work directory"
 #define   MCHelpSwX          "\n  x<file>       Exclude specified file"
 #define   MCHelpSwXa         "\n  x@            Read file names to exclude from stdin"
-#define   MCHelpSwXal        "\n  x@<list>      Exclude files in specified list file"
+#define   MCHelpSwXal        "\n  x@<list>      Exclude files listed in specified list file"
 #define   MCHelpSwY          "\n  y             Assume Yes on all queries"
 #define   MCHelpSwZ          "\n  z[file]       Read archive comment from file"
 #define   MBadArc            "\nERROR: Bad archive %s\n"
@@ -215,7 +219,7 @@
 #define   MExtrPoints        "\n...         %-56s"
 #define   MExtrErrMkDir      "\nCannot create directory %s"
 #define   MExtrPrinting      "\n------ Printing %s\n\n"
-#define   MEncrBadCRC        "\nEncrypted file:  CRC failed in %s (password incorrect ?)"
+#define   MEncrBadCRC        "\nCRC failed in the encrypted file %s. Corrupt file or wrong password."
 #define   MExtrNoFiles       "\nNo files to extract"
 #define   MExtrAllOk         "\nAll OK"
 #define   MExtrTotalErr      "\nTotal errors: %ld"
@@ -235,7 +239,6 @@
 #define   MLogCommBrk        "\nThe archive comment is corrupt"
 #define   MCommAskCont       "\nPress 'Enter' to continue or 'Q' to quit:"
 #define   MLogBrokFCmt       "\nThe file comment is corrupt"
-#define   MAbsDestName       "\nDestination file name required"
 #define   MWriteCommTo       "\nWrite comment to %s"
 #define   MCommNotPres       "\nComment is not present"
 #define   MDelFrom           "\nDeleting from %s"
@@ -346,3 +349,6 @@
 #define   MVolumeNumber      "volume %d"
 #define   MCannotDelete      "\nCannot delete %s"
 #define   MCalcCRC           "\nCalculating the control sum"
+#define   MTooLargeSFXArc    "\nWARNING: Too large SFX archive. Windows cannot run the executable file exceeding 4 GB."
+#define   MCalcCRCAllVol     "\nCalculating control sums of all volumes."
+#define   MNotEnoughDisk     "\nERROR: Not enough disk space for %s."
